//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[FuroChanceShantenResult](index.md)/[FuroChanceShantenResult](-furo-chance-shanten-result.md)

# FuroChanceShantenResult

[common]\
constructor(hand: [Hand](../../mahjongutils.models.hand/-hand/index.md)&lt;[RegularHandPattern](../../mahjongutils.models.hand/-regular-hand-pattern/index.md)&gt;, shantenInfo: [ShantenWithFuroChance](../-shanten-with-furo-chance/index.md))
